@@ -515,7 +515,8 @@ class LaggedAnalyser(object):
         else:
             pval_ds=pval_ds<p
             
-        return pval_ds.assign_coords(lag=comp.lag)    
+        self.composite_sigs=pval_ds.assign_coords(lag=comp.lag)
+        return self.composite_sigs
     
     def bootstrap_significance(self,bootnum,p,dim='time',synth_mode='markov',reuse_lag0_boots=False,data_vars=None,hb_correction=False):
         
